# Delta to Meta Model v3
### On this page
  * [Quick links](https://help.sap.com/docs/leanix/ea/delta-to-meta-model-v3#quick-links)
  * [Why has SAP LeanIX changed its Meta Model?](https://help.sap.com/docs/leanix/ea/delta-to-meta-model-v3#why-has-sap-leanix-changed-its-meta-model?)
  * [What is the delta between the Meta Model v4 and the Meta Model v3?](https://help.sap.com/docs/leanix/ea/delta-to-meta-model-v3#what-is-the-delta-between-the-meta-model-v4-and-the-meta-model-v3?)
  * [Q&A on detailed changes](https://help.sap.com/docs/leanix/ea/delta-to-meta-model-v3#q&a-on-detailed-changes)


**Note**
This page is only relevant for existing customers of SAP LeanIX who have been working with the previous Meta Model v3 to learn about the key changes and how to apply the Meta Model v4. Please refer to the Modeling Guidelines of the Meta Model v4 for more information on each Fact Sheet type.
SAP LeanIX has updated its [Meta Model v3](https://help.sap.com/docs/leanix/ea/meta-model-v3?locale=en-US&state=PRODUCTION&version=CLOUD) and is rolling out the evolved Meta Model v4 to workspaces for new customers. Existing customers using the [Meta Model v3](https://help.sap.com/docs/leanix/ea/meta-model-v3?locale=en-US&state=PRODUCTION&version=CLOUD) are not obliged to change it but can decide proactively to use the [Meta Model v4](https://help.sap.com/docs/leanix/ea/meta-model?locale=en-US&state=PRODUCTION&version=CLOUD "Get an overview of the SAP LeanIX meta model and its key concepts."). This page provides detailed information on the rationale, answers frequently asked questions, and gives an overview of the delta between the evolved and the [Meta Model v3](https://help.sap.com/docs/leanix/ea/meta-model-v3?locale=en-US&state=PRODUCTION&version=CLOUD).
